Skip to contents

Use the dataframe from clean_file() and the mkpro() function to reverse scores, then calculate totals, missingness, and pro-rated totals for the total test and subdomains

Usage

build_summary_swan(df = NULL)

Arguments

df

should be a data.frame from clean_file()

Value

A data frame with all of the totals columns