Skip to contents

Use the dataframe from clean_file() and the mkpro() function to reverse scores, then calculate totals, missingness, and pro-rated totals for the total test and subdomains

Usage

build_summary_tocs(df = NULL, max_missing = NULL)

Arguments

df

should be a data.frame from clean_file()

max_missing

max_missing is passed from the score_tocs2() function. By default, the tocs allows 0 missing items.

Value

A data frame with all of the totals columns