This is the generic model used to create t-scores. It adjusts for gender, age, respondent, and time.
It is best used in all cases unless a team is trying to look at values over time
Use the dataframe from build_summary_swan() to produce t-scores
Arguments
- df
should be a data.frame from
build_summary_swan()